import { PropType } from 'vue';
import { Layout } from './helpers/utils';
export declare const propsGridLayout: {
    /**
     * Layout 容器是否自动调整大小，以容纳所有 Item
     */
    autoSize: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * 定义栅格系统的列数
     */
    colNum: {
        type: NumberConstructor;
        default: number;
    };
    /**
     * 栅格每行的高度，单位像素
     */
    rowHeight: {
        type: NumberConstructor;
        default: number;
    };
    /**
     * 最大行数
     */
    maxRows: {
        type: NumberConstructor;
        default: number;
    };
    /**
     * 定义栅格中的元素边距。值必须是包含两个 Number的数组，数组中第一个元素表示水平边距，第二个表示垂直边距，单位为像素。
     */
    margin: {
        type: PropType<number[]>;
        default: () => number[];
    };
    /**
     * 栅格中的元素是否可拖拽
     */
    isDraggable: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * 栅格中的元素是否可调整大小。
     */
    isResizable: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * 栅格中的元素是否可镜像反转。
     */
    isMirrored: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * 是否使用CSS属性 transition-property: transform;
     */
    useCssTransforms: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * 布局是否垂直压缩。
     */
    verticalCompact: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * 栅格的初始布局。值必须为 Array，其数据项为 Object。 每条数据项必须有 i, x, y, w 和 h 属性。
     */
    layout: {
        type: PropType<Layout>;
        required: boolean;
    };
    /**
     * 布局是否为响应式。
     */
    responsive: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * 如果 responsive 设置为 true，该配置将作为栅格中每个断点的初始布局。
     * 键值是断点名称，每项的值都是类似 layout 属性定义的数据结构，值必须为 Array，其数据项为 Object。
     * 例如： {lg: [layout items], md: [layout items]}。需要注意的是，在创建栅格布局后设置该属性无效。
     * 在创建GridLayout之后设置prop无效。
     */
    responsiveLayouts: {
        type: ObjectConstructor;
        default: () => {};
    };
    /**
     * 为响应式布局设置断点。
     */
    breakpoints: {
        type: ObjectConstructor;
        default: () => {
            lg: number;
            md: number;
            sm: number;
            xs: number;
            xxs: number;
        };
    };
    /**
     * 设置每个断点对应的列数。
     */
    responsiveCols: {
        type: ObjectConstructor;
        default: () => {
            lg: number;
            md: number;
            sm: number;
            xs: number;
            xxs: number;
        };
    };
    /**
     * 防止碰撞属性，值设置为 true 时，栅格只能拖动至空白处。
     */
    preventCollision: {
        type: BooleanConstructor;
        default: boolean;
    };
};
export declare const propsGridItem: {
    isDraggable: {
        type: BooleanConstructor;
        default: boolean;
    };
    isResizable: {
        type: BooleanConstructor;
        default: boolean;
    };
    static: {
        type: BooleanConstructor;
        default: boolean;
    };
    minH: {
        type: NumberConstructor;
        default: number;
    };
    minW: {
        type: NumberConstructor;
        default: number;
    };
    maxH: {
        type: NumberConstructor;
        default: number;
    };
    maxW: {
        type: NumberConstructor;
        default: number;
    };
    x: {
        type: NumberConstructor;
        required: boolean;
    };
    y: {
        type: NumberConstructor;
        required: boolean;
    };
    w: {
        type: NumberConstructor;
        required: boolean;
    };
    h: {
        type: NumberConstructor;
        required: boolean;
    };
    i: {
        type: (NumberConstructor | StringConstructor)[];
        required: boolean;
    };
    dragIgnoreFrom: {
        type: StringConstructor;
        default: string;
    };
    dragAllowFrom: {
        type: StringConstructor;
        default: string;
    };
    resizeIgnoreFrom: {
        type: StringConstructor;
        default: string;
    };
};
